@@ -2,7 +2,7 @@
 #'
 #' Provides an interface to the CrossRef API, searching for citations given a string query.  Results are written to a
 #' bib file, read back into \code{R} using \code{\link{WriteBib}}, and returned as a BibEntry object.
-#' 
+#'
 #' @param query string; search term
 #' @param limit numeric; maximum number of entries to return
 #' @param sort string; how should the results from CrossRef be returned.
@@ -13,7 +13,7 @@
 #' @param verbose boolean; if \code{TRUE}, additional messages are output regarding the results of the query.
 #' @return An object of class BibEntry.
 #' @details CrossRef assigns a score between 0 and 100 based on how relevant a reference seems to be
-#' to your query.  The API documentation warns that while false negatives are unlikely, the search can be prone 
+#' to your query.  The API documentation warns that while false negatives are unlikely, the search can be prone
 #' to false positives.  Hence, setting \code{min.revelance} to a high value may be necessary.
 #' @importFrom RJSONIO fromJSON
 #' @importFrom RCurl getForm getURLContent
@@ -23,9 +23,9 @@
 #' @family pubmed
 #' @references \url{http://search.crossref.org/help/api}
 #' @examples
-#' ReadCrossRef(query = 'rj carroll measurement error', limit = 2, sort = "relevance", 
+#' ReadCrossRef(query = 'rj carroll measurement error', limit = 2, sort = "relevance",
 #'   min.relevance = 80)
-#' 
+#'
 #' ReadCrossRef(query = 'carroll journal of the american statistical association',
 #'   year = 2012, limit = 2)
 ReadCrossRef <- function(query, limit = 5, sort = 'relevance', year = NULL, min.relevance = 80,
@@ -33,27 +33,27 @@ ReadCrossRef <- function(query, limit = 5, sort = 'relevance', year = NULL, min.
   if (is.na(query))
     return(NA)
   good <- 0
-  
+
   file.create(temp.file)
   if (delete.file)
    on.exit(unlink(temp.file, force = TRUE))
   # if query is valid doi, skip search and get BibTeX entry right away
   if (!is.na(.doi <- SearchDOIText(query))){
-    
+
     good <- GetCrossRefBibTeX(paste0('http://dx.doi.org/', .doi), temp.file)
   }else{
-    results <- try(getForm("http://search.labs.crossref.org/dois", q=query, year=year, sort=sort,  
+    results <- try(getForm("http://search.labs.crossref.org/dois", q=query, year=year, sort=sort,
                        rows=limit))
     if (inherits(results, 'try-error'))
       return(NA)
-    
+
     fromj <- RJSONIO::fromJSON(results)
     num.res <- min(limit, length(fromj))
     if(num.res == 0L){
       message(paste0('Query \"', query, '\" returned no matches'))
       return(NA)
     }
-  
+
     if (num.res > 0L){
       file.create(temp.file)
      # entries <- vector('character', num.res)
@@ -90,6 +90,7 @@ GetCrossRefBibTeX <- function(doi, tmp.file){
     return(0L)
   }
   temp <- gsub('&amp;', '&', temp)
+  temp <- sub("^@[Dd]ata", "@online", temp)  # Crossref uses data type for some entries
   write(temp, file = tmp.file, append=TRUE)
   return(1L)
 }
